@@ -407,6 +407,31 @@ class Graph:
         with open(filename, "w+") as file:
             file.write(txtout)
 
+    def get_satx_as_txt(self):
+        txtout = ""
+
+        lookup_table = self.get_lookup_table()
+        cell_names, edges, _ = self.get_all_cells_edges()
+        cells = [self.get_cell(cn) for cn in cell_names]
+
+        for c in cells:
+            if c.content:
+                fill_with_code = "y:\n"
+            else:
+                fill_with_code = "n\n"
+            temp_text = "cell " + c.name + " " + c.content_type + " " + fill_with_code
+            if fill_with_code == "y:\n":
+                temp_text += c.content + ";\n"
+
+            txtout += temp_text
+
+        for e in edges:
+            name1 = lookup_table[e[0]]
+            name2 = lookup_table[e[1]]
+            txtout += "link " + name1 + " " + name2 + "\n"
+
+        return txtout
+
 
 class Interpreter:
 
@@ -835,4 +860,18 @@ def create_app(test_config=None):
 
         return "true"
 
+    @app.route("/shutdown/", methods=["POST"])
+    def shutdown():
+        funct = request.environ.get('werkzeug.server.shutdown')
+        if funct is None:
+            raise RuntimeError("Not running with the Werkzeug Server")
+        funct()
+
+        return "done"
+
+    @app.route("/get_satx_text/", methods=["POST"])
+    def get_satx_text():
+        satx_txt = interpreter.graph.get_satx_as_txt()
+        return satx_txt
+
     return app
\ No newline at end of file
